@@ -4,6 +4,7 @@
 
 import pandas
 import defusedxml.cElementTree as ETree
+from pysqa.wrapper.generic import SchedulerCommands
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -17,7 +18,7 @@ __status__ = "production"
 __date__ = "Feb 9, 2019"
 
 
-class SunGridEngineCommands(object):
+class SunGridEngineCommands(SchedulerCommands):
     @property
     def submit_job_command(self):
         return ["qsub", "-terse"]
@@ -34,10 +35,6 @@ class SunGridEngineCommands(object):
     def get_queue_status_command(self):
         return ["qstat", "-xml"]
 
-    @staticmethod
-    def get_job_id_from_output(queue_submit_output):
-        return int(queue_submit_output)
-
     @staticmethod
     def convert_queue_status(queue_status_output):
         def leaf_to_dict(leaf):
