@@ -3,6 +3,7 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
 import pandas
+from pysqa.wrapper.generic import SchedulerCommands
 
 
 __author__ = "Jan Janssen"
@@ -17,7 +18,7 @@ __status__ = "development"
 __date__ = "Feb 9, 2019"
 
 
-class SlurmCommands(object):
+class SlurmCommands(SchedulerCommands):
     @property
     def submit_job_command(self):
         return ["sbatch", "--parsable"]
@@ -26,13 +27,9 @@ class SlurmCommands(object):
     def delete_job_command(self):
         return ["scancel"]
 
-    @property
-    def enable_reservation_command(self):
-        raise NotImplementedError()
-
     @property
     def get_queue_status_command(self):
-        return ["squeue", "--format", "%A|%u|%t|%j", "--noheader"]
+        return ["squeue", "--format", "%A|%u|%t|%.15j", "--noheader"]
 
     @staticmethod
     def get_job_id_from_output(queue_submit_output):
@@ -61,3 +58,10 @@ class SlurmCommands(object):
         df.loc[df.status == "r", "status"] = "running"
         df.loc[df.status == "pd", "status"] = "pending"
         return df
+
+    @staticmethod
+    def dependencies(dependency_list) -> list:
+        if dependency_list is not None:
+            return ["--dependency=afterok:" + ",".join(dependency_list)]
+        else:
+            return []
